@@ -6,7 +6,7 @@ import sys, time, logging
 import numpy as np
 from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
-from . import cocos
+from aug_sfutils import cocos
 
 logger = logging.getLogger('aug_sfutils.mapeq')
 
