@@ -37,7 +37,7 @@ obj_name = {1: 'Diagnostic', 2: 'List', 3: 'Device', 4: 'Param_Set', \
             5: 'Map_Func', 6: 'Signal Group', 7: 'Signal', 8: 'Time Base', \
             9: 'SF_List', 10: 'Algorithm', 11: 'Update_Set', \
             12: 'Loc_Timer', 13: 'Area Base', 14: 'Qualifier', \
-            15: 'ModObj', 16: 'Map_Extd', 17: 'Resource'}
+            15: 'ModObj', 16: 'Map_Extd', 17: 'Resource', 18: 'Unknown'}
 
 cal_type = {0: 'NoCalib', 1: 'LinCalib', 2: 'LookUp-Tab', 3: 'extCalib'}
 
