@@ -1,7 +1,7 @@
 import shutil, os, logging
 import ctypes as ct
 import numpy as np
-from . import sfdics, str_byt
+from aug_sfutils import sfdics, str_byt
 
 sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
 libsfh = ct.cdll.LoadLibrary(sfhlib)
