@@ -22,6 +22,7 @@ def read_sfh(byt_str):
         sfo = SFH_READ(byt_str[j*128: (j+1)*128])
         typ =  sfo.obj_type
         onam = str_byt.to_str(sfo.objnam.strip())
+        logger.debug('%d %s %d %s', j, onam, typ, sfdics.obj_name[typ])
         if typ == 1:
             sfo.diag()
             if n_obj == n_max:
@@ -71,6 +72,7 @@ class SFH_READ:
         """
         self.objnam   = str_byt.to_str(byte_str[0:8].strip())
         self.obj_type, self.level, self.status = unpack('>3H', byte_str[ 8: 14])
+        logger.debug('%s %d', self.objnam, self.obj_type)
         self.object_type = sfdics.obj_name[self.obj_type]
         self.errcode  = unpack('>h', byte_str[14: 16])[0]
         fmt = '>%dH' %n_rel
